==> qtjambi-network-debuginfo-windows-x64-6.5.6.jar: sources/QtJambiNetwork/QDnsHostAddressRecord_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtnetwork-config.h>
#if QT_CONFIG(dnslookup)
#include <QtNetwork/qdnslookup.h>
#endif //QT_CONFIG(dnslookup)
#include <QtCore/QVariant>
#include <QtNetwork/qhostaddress.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(dnslookup)


void deleter_QDnsHostAddressRecord(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDnsHostAddressRecord")
    QDnsHostAddressRecord *_ptr = reinterpret_cast<QDnsHostAddressRecord *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(dnslookup)

// emitting (writeConstructors)
// new QDnsHostAddressRecord()
void __qt_construct_QDnsHostAddressRecord(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsHostAddressRecord()")
#if QT_CONFIG(dnslookup)
    Q_UNUSED(__java_arguments)
    QDnsHostAddressRecord *__qt_this = new(__qtjambi_ptr) QDnsHostAddressRecord();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// QDnsHostAddressRecord::QDnsHostAddressRecord()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_initialize_1native__Lio_qt_network_QDnsHostAddressRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsHostAddressRecord::QDnsHostAddressRecord()")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsHostAddressRecord, sizeof(QDnsHostAddressRecord), typeid(QDnsHostAddressRecord), false, &deleter_QDnsHostAddressRecord, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDnsHostAddressRecord(QDnsHostAddressRecord)
void __qt_construct_QDnsHostAddressRecord_cref_QDnsHostAddressRecord(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsHostAddressRecord(QDnsHostAddressRecord)")
#if QT_CONFIG(dnslookup)
    jobject other0 = __java_arguments[0].l;
    const QDnsHostAddressRecord& __qt_other0 = qtjambi_cast<const QDnsHostAddressRecord& >(__jni_env, other0);
    QDnsHostAddressRecord *__qt_this = new(__qtjambi_ptr) QDnsHostAddressRecord(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// QDnsHostAddressRecord::QDnsHostAddressRecord(QDnsHostAddressRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_initialize_1native__Lio_qt_network_QDnsHostAddressRecord_2Lio_qt_network_QDnsHostAddressRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsHostAddressRecord::QDnsHostAddressRecord(QDnsHostAddressRecord)")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsHostAddressRecord_cref_QDnsHostAddressRecord, sizeof(QDnsHostAddressRecord), typeid(QDnsHostAddressRecord), false, &deleter_QDnsHostAddressRecord, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDnsHostAddressRecord
void __qt_destruct_QDnsHostAddressRecord(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDnsHostAddressRecord")

#if QT_CONFIG(dnslookup)

    reinterpret_cast<QDnsHostAddressRecord*>(ptr)->~QDnsHostAddressRecord();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(dnslookup)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDnsHostAddressRecord::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsHostAddressRecord::operator=(QDnsHostAddressRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_assign_1native_1cref_1QDnsHostAddressRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::operator=(QDnsHostAddressRecord)", __qt_this)
        const QDnsHostAddressRecord& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDnsHostAddressRecord>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsHostAddressRecord::swap(QDnsHostAddressRecord&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_swap_1native_1ref_1QDnsHostAddressRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::swap(QDnsHostAddressRecord&)", __qt_this)
        QDnsHostAddressRecord& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDnsHostAddressRecord>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsHostAddressRecord::timeToLive()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_timeToLive_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::timeToLive()const", __qt_this)
        quint32 __qt_return_value = __qt_this->timeToLive();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsHostAddressRecord::value()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::value()const", __qt_this)
        QHostAddress __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(dnslookup)

        const QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(dnslookup)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDnsHostAddressRecord(){
    using namespace RegistryAPI;

#if QT_CONFIG(dnslookup)

    const std::type_info& typeId = registerValueTypeInfo<QDnsHostAddressRecord>("QDnsHostAddressRecord", "io/qt/network/QDnsHostAddressRecord");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDnsHostAddressRecord, {
        ConstructorInfo(&__qt_construct_QDnsHostAddressRecord, nullptr)
       ,ConstructorInfo(&__qt_construct_QDnsHostAddressRecord_cref_QDnsHostAddressRecord, "Lio/qt/network/QDnsHostAddressRecord;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDnsHostAddressRecord);
    registerMetaType<QDnsHostAddressRecord>("QDnsHostAddressRecord");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(dnslookup)

}

==> qtjambi-network-debuginfo-windows-x64-6.5.7.jar: sources/QtJambiNetwork/QDnsHostAddressRecord_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtnetwork-config.h>
#if QT_CONFIG(dnslookup)
#include <QtNetwork/qdnslookup.h>
#endif //QT_CONFIG(dnslookup)
#include <QtCore/QVariant>
#include <QtNetwork/qhostaddress.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(dnslookup)


void deleter_QDnsHostAddressRecord(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDnsHostAddressRecord")
    QDnsHostAddressRecord *_ptr = reinterpret_cast<QDnsHostAddressRecord *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(dnslookup)

// emitting (writeConstructors)
// new QDnsHostAddressRecord()
void __qt_construct_QDnsHostAddressRecord(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsHostAddressRecord()")
#if QT_CONFIG(dnslookup)
    Q_UNUSED(__java_arguments)
    QDnsHostAddressRecord *__qt_this = new(__qtjambi_ptr) QDnsHostAddressRecord();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// QDnsHostAddressRecord::QDnsHostAddressRecord()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_initialize_1native__Lio_qt_network_QDnsHostAddressRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsHostAddressRecord::QDnsHostAddressRecord()")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsHostAddressRecord, sizeof(QDnsHostAddressRecord), typeid(QDnsHostAddressRecord), 0, false, &deleter_QDnsHostAddressRecord, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDnsHostAddressRecord(QDnsHostAddressRecord)
void __qt_construct_QDnsHostAddressRecord_cref_QDnsHostAddressRecord(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDnsHostAddressRecord(QDnsHostAddressRecord)")
#if QT_CONFIG(dnslookup)
    jobject other0 = __java_arguments[0].l;
    const QDnsHostAddressRecord& __qt_other0 = qtjambi_cast<const QDnsHostAddressRecord&>(__jni_env, other0);
    QDnsHostAddressRecord *__qt_this = new(__qtjambi_ptr) QDnsHostAddressRecord(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
}

// QDnsHostAddressRecord::QDnsHostAddressRecord(QDnsHostAddressRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_initialize_1native__Lio_qt_network_QDnsHostAddressRecord_2Lio_qt_network_QDnsHostAddressRecord_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDnsHostAddressRecord::QDnsHostAddressRecord(QDnsHostAddressRecord)")
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDnsHostAddressRecord_cref_QDnsHostAddressRecord, sizeof(QDnsHostAddressRecord), typeid(QDnsHostAddressRecord), 0, false, &deleter_QDnsHostAddressRecord, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDnsHostAddressRecord
void __qt_destruct_QDnsHostAddressRecord(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDnsHostAddressRecord")

#if QT_CONFIG(dnslookup)

    reinterpret_cast<QDnsHostAddressRecord*>(ptr)->~QDnsHostAddressRecord();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(dnslookup)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDnsHostAddressRecord::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::name()const", __this_nativeId)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsHostAddressRecord::operator=(QDnsHostAddressRecord)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_assign_1native_1cref_1QDnsHostAddressRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::operator=(QDnsHostAddressRecord)", __this_nativeId)
        const QDnsHostAddressRecord& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDnsHostAddressRecord>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsHostAddressRecord::swap(QDnsHostAddressRecord&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_swap_1native_1ref_1QDnsHostAddressRecord__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::swap(QDnsHostAddressRecord&)", __this_nativeId)
        QDnsHostAddressRecord& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDnsHostAddressRecord>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDnsHostAddressRecord::timeToLive()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_timeToLive_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::timeToLive()const", __this_nativeId)
        quint32 __qt_return_value = __qt_this->timeToLive();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDnsHostAddressRecord::value()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(dnslookup)
        const QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDnsHostAddressRecord::value()const", __this_nativeId)
        QHostAddress __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(dnslookup)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QDnsHostAddressRecord_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(dnslookup)

        const QDnsHostAddressRecord *__qt_this = QtJambiAPI::objectFromNativeId<QDnsHostAddressRecord>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(dnslookup)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDnsHostAddressRecord(){
    using namespace RegistryAPI;

#if QT_CONFIG(dnslookup)

    const std::type_info& typeId = registerValueTypeInfo<QDnsHostAddressRecord>("QDnsHostAddressRecord", "io/qt/network/QDnsHostAddressRecord");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDnsHostAddressRecord, {
        ConstructorInfo(&__qt_construct_QDnsHostAddressRecord, nullptr)
       ,ConstructorInfo(&__qt_construct_QDnsHostAddressRecord_cref_QDnsHostAddressRecord, "Lio/qt/network/QDnsHostAddressRecord;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDnsHostAddressRecord);
    registerMetaType<QDnsHostAddressRecord>("QDnsHostAddressRecord");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(dnslookup)

}
